==> senior_design_system-0.10.13.tar.gz: example/lib/views/button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../panel.dart';
import '../page_wrapper.dart';

class ButtonExample extends StatefulWidget {
  const ButtonExample({Key? key}) : super(key: key);

  @override
  _ButtonExampleState createState() => _ButtonExampleState();
}

class _ButtonExampleState extends State<ButtonExample> {
  bool _isDisabled = false;
  bool _isBusy = false;

  void _showSnackbar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(message),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Button Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !this._isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    this._isDisabled = !value;
                  });
                },
                labelPosition: SeniorSwitchLabelPosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Primary button',
                      content: SeniorButton(
                        label: 'Salvar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Salvar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button',
                      content: SeniorButton(
                        label: 'Revisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Revisar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button',
                      content: SeniorButton(
                        label: 'Cancelar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Cancelar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Danger button',
                      content: SeniorButton(
                        label: 'Excluir',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Excluir com largura ocupando todo o espaço disponível',
                        ),
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.danger,
                      ),
                    ),
                    Panel(
                      title: 'Aligned button',
                      content: Row(
                        children: [
                          Expanded(
                            child: SeniorButton(
                              label: 'OK',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Salvar.',
                              ),
                              disabled: this._isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.primary,
                            ),
                          ),
                          SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Editar',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Revisar',
                              ),
                              disabled: this._isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.secondary,
                            ),
                          ),
                          SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Sair',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Cancelar',
                              ),
                              disabled: this._isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.ghost,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Primary button with icon',
                      content: SeniorButton.icon(
                        icon: FontAwesomeIcons.search,
                        label: 'Pesquisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Pesquisar que possui ícone',
                        ),
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button with icon',
                      content: SeniorButton.icon(
                        icon: FontAwesomeIcons.edit,
                        label: 'Editar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Editar que possui ícone',
                        ),
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button with icon',
                      content: SeniorButton.icon(
                        icon: FontAwesomeIcons.times,
                        label: 'Fechar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Fechar que possui ícone',
                        ),
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Button with progress animation',
                      content: SeniorButton(
                        label: 'Progress',
                        onPressed: () {
                          setState(() {
                            this._isBusy = !this._isBusy;
                          });
                        },
                        disabled: this._isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                        busy: this._isBusy,
                        busyMessage: 'Botão ocupado',
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-0.17.0.tar.gz: example/lib/views/button.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import '../panel.dart';
import '../page_wrapper.dart';

class ButtonExample extends StatefulWidget {
  const ButtonExample({Key? key}) : super(key: key);

  @override
  _ButtonExampleState createState() => _ButtonExampleState();
}

class _ButtonExampleState extends State<ButtonExample> {
  bool _isDisabled = false;
  bool _isBusy = false;

  void _showSnackbar({
    required BuildContext context,
    required String message,
  }) {
    final scaffold = ScaffoldMessenger.of(context);
    scaffold.showSnackBar(
      SnackBar(
        content: Text(message),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Button Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.only(top: 16.0),
          child: Column(
            children: [
              SeniorSwitch(
                title: 'Habilitar botões',
                value: !_isDisabled,
                onChanged: (value) {
                  if (value == null) return;
                  setState(() {
                    _isDisabled = !value;
                  });
                },
                titlePosition: SeniorSwitchTitlePosition.right,
              ),
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Column(
                  children: [
                    Panel(
                      title: 'Primary button',
                      content: SeniorButton(
                        label: 'Salvar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Salvar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button',
                      content: SeniorButton(
                        label: 'Revisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Revisar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button',
                      content: SeniorButton(
                        label: 'Cancelar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Cancelar com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Danger button',
                      content: SeniorButton(
                        label: 'Excluir',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Excluir com largura ocupando todo o espaço disponível',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.danger,
                      ),
                    ),
                    Panel(
                      title: 'Aligned button',
                      content: Row(
                        children: [
                          Expanded(
                            child: SeniorButton(
                              label: 'OK',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Salvar.',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.primary,
                            ),
                          ),
                          SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Editar',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Revisar',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.secondary,
                            ),
                          ),
                          SizedBox(width: 16.0),
                          Expanded(
                            child: SeniorButton(
                              label: 'Sair',
                              onPressed: () => _showSnackbar(
                                context: context,
                                message: 'Clicou sobre o botão Cancelar',
                              ),
                              disabled: _isDisabled,
                              fullLength: true,
                              size: SeniorButtonSize.big,
                              type: SeniorButtonType.ghost,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Panel(
                      title: 'Primary button with icon',
                      content: SeniorButton.icon(
                        icon: FontAwesomeIcons.search,
                        label: 'Pesquisar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Pesquisar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.primary,
                      ),
                    ),
                    Panel(
                      title: 'Secondary button with icon',
                      content: SeniorButton.icon(
                        icon: FontAwesomeIcons.edit,
                        label: 'Editar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Editar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.secondary,
                      ),
                    ),
                    Panel(
                      title: 'Ghost button with icon',
                      content: SeniorButton.icon(
                        icon: FontAwesomeIcons.times,
                        label: 'Fechar',
                        onPressed: () => _showSnackbar(
                          context: context,
                          message: 'Clicou sobre o botão Fechar que possui ícone',
                        ),
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.small,
                        type: SeniorButtonType.ghost,
                      ),
                    ),
                    Panel(
                      title: 'Button with progress animation',
                      content: SeniorButton(
                        label: 'Progress',
                        onPressed: () {
                          setState(() {
                            _isBusy = !_isBusy;
                          });
                        },
                        disabled: _isDisabled,
                        fullLength: true,
                        size: SeniorButtonSize.big,
                        type: SeniorButtonType.primary,
                        busy: _isBusy,
                        busyMessage: 'Botão ocupado',
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
